/*
   +----------------------------------------------------------------------+
   | PHP version 4.0                                                      |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997, 1998, 1999, 2000, 2001 The PHP Group             |
   +----------------------------------------------------------------------+
   | This source file is subject to version 2.02 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available at through the world-wide-web at                           |
   | http://www.php.net/license/2_02.txt.                                 |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors:                                                             |
   |                                                                      |
   +----------------------------------------------------------------------+
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "ext/standard/info.h"
#include "php_test.h"

ZEND_DECLARE_MODULE_GLOBALS(test)

/* True global resources - no need for thread safety here */
static int le_test;

/* {{{ test_functions[]
 *
 * Every user visible function must have an entry in test_functions[].
 */
function_entry test_functions[] = {
	PHP_FE(get_value,	NULL)		/* For testing, remove later. */
	{NULL, NULL, NULL}	/* Must be the last line in test_functions[] */
};
/* }}} */

/* {{{ test_module_entry
 */
zend_module_entry test_module_entry = {
	STANDARD_MODULE_HEADER,
	"test",
	test_functions,
	PHP_MINIT(test),
	PHP_MSHUTDOWN(test),
	PHP_RINIT(test),		/* Replace with NULL if there's nothing to do at request start */
	PHP_RSHUTDOWN(test),	/* Replace with NULL if there's nothing to do at request end */
	PHP_MINFO(test),
    "0.1", /* Replace with version number for your extension */
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_TEST
ZEND_GET_MODULE(test)
#endif

/* {{{ PHP_INI
 */
/* Remove comments and fill if you need to have entries in php.ini
PHP_INI_BEGIN()
    STD_PHP_INI_ENTRY("test.value",      "42", PHP_INI_ALL, OnUpdateInt, global_value, zend_test_globals, test_globals)
    STD_PHP_INI_ENTRY("test.string", "foobar", PHP_INI_ALL, OnUpdateString, global_string, zend_test_globals, test_globals)
PHP_INI_END()
*/
/* }}} */

void delete_friggin_type(void *data)
{
}

/* {{{ php_test_init_globals
 */
static void php_test_init_globals(zend_test_globals *test_globals)
{
	test_globals->global_hash = emalloc(sizeof(HashTable));
	zend_hash_init(test_globals->global_hash, 0, NULL, delete_friggin_type, 0);

	zend_hash_add(test_globals->global_hash, "mykey", strlen("mykey"), "myvalue", strlen("myvalue"), NULL);
}
/* }}} */

/* {{{ PHP_MINIT_FUNCTION
 */
PHP_MINIT_FUNCTION(test)
{
//	ZEND_INIT_MODULE_GLOBALS(test, php_test_init_globals, NULL);
	TEST_G(global_hash) = emalloc(sizeof(HashTable));
	zend_hash_init(TEST_G(global_hash), 0, NULL, delete_friggin_type, 0);

	zend_hash_add(TEST_G(global_hash), "mykey", sizeof("mykey"), "myvalue", sizeof("myvalue"), NULL);
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION
 */
PHP_MSHUTDOWN_FUNCTION(test)
{
	/* uncomment this line if you have INI entries
	UNREGISTER_INI_ENTRIES();
	*/
	return SUCCESS;
}
/* }}} */

/* Remove if there's nothing to do at request start */
/* {{{ PHP_RINIT_FUNCTION
 */
PHP_RINIT_FUNCTION(test)
{
	return SUCCESS;
}
/* }}} */

/* Remove if there's nothing to do at request end */
/* {{{ PHP_RSHUTDOWN_FUNCTION
 */
PHP_RSHUTDOWN_FUNCTION(test)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION
 */
PHP_MINFO_FUNCTION(test)
{
	php_info_print_table_start();
	php_info_print_table_header(2, "test support", "enabled");
	php_info_print_table_end();

	/* Remove comments if you have entries in php.ini
	DISPLAY_INI_ENTRIES();
	*/
}
/* }}} */

/* {{{ proto string confirm_test_compiled(string arg)
   Return a string to confirm that the module is compiled in */
PHP_FUNCTION(get_value)
{
	char *arg = NULL;

	if(zend_hash_find(TEST_G(global_hash), "mykey", sizeof("mykey"), &arg) != FAILURE)
	{
		RETURN_STRING(arg, 1);
	}
	else
	{
		RETURN_STRING("failed", 1);
	}
}
/* }}} */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: sw=4 ts=4 tw=78 fdm=marker
 * vim<600: sw=4 ts=4 tw=78
 */
